Common options to all cartesian axes | Chart.js
Description: Open source HTML5 Charts for your website

### # Common options to all cartesian axes

Namespace: `options.scales[scaleId]`

Name | Type | Default | Description
--- | --- | --- | ---
`bounds` | `string` | `'ticks'` | Determines the scale bounds. more...
`position` | `string` | `object` |  | Position of the axis. more...
`stack` | `string` |  | Stack group. Axes at the same `position` with same `stack` are stacked.
`stackWeight` | `number` | 1 | Weight of the scale in stack group. Used to determine the amount of allocated space for the scale within the group.
`axis` | `string` |  | Which type of axis this is. Possible values are: `'x'`, `'y'`. If not set, this is inferred from the first character of the ID which should be `'x'` or `'y'`.
`offset` | `boolean` | `false` | If true, extra space is added to the both edges and the axis is scaled to fit into the chart area. This is set to `true` for a bar chart by default.
`title` | `object` |  | Scale title configuration. more...